----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch>
--
-- Module Name: scalp_firmware - arch
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2019.2
-- Description: scalp_firmware
--
-- Last update: 2020-11-10
--
---------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

library work;
-- Aurora packages
use work.aurora_status_pkg.all;
use work.aurora_drp_pkg.all;
-- Axi4 packages
use work.axi4_pkg.all;

library unisim;
use unisim.vcomponents.all;

entity scalp_firmware is

    generic (
        C_USE_IBERT  : boolean := false;
        C_DEBUG_MODE : boolean := false);

    port (
        -----------------------------------------------------------------------
        -- Names defined and not described in the constraint file.
        -----------------------------------------------------------------------
        -- Zynq FIXED_IO
        PSClkxCIO          : inout std_logic;
        PSSRstxRNIO        : inout std_logic;
        PSPorxSNIO         : inout std_logic;
        -- DDR interface
        DDRClkNxCIO        : inout std_logic;
        DDRClkPxCIO        : inout std_logic;
        DDRDRstxRNIO       : inout std_logic;
        DDRCasNxSIO        : inout std_logic;
        DDRCkexSIO         : inout std_logic;
        DDRCsNxSIO         : inout std_logic;
        DDROdtxSIO         : inout std_logic;
        DDRRasNxSIO        : inout std_logic;
        DDRWexSNIO         : inout std_logic;
        DDRBankAddrxDIO    : inout std_logic_vector(2 downto 0);
        DDRAddrxDIO        : inout std_logic_vector(14 downto 0);
        DDRVrNxSIO         : inout std_logic;
        DDRVrPxSIO         : inout std_logic;
        DDRDmxDIO          : inout std_logic_vector(3 downto 0);
        DDRDqxDIO          : inout std_logic_vector(31 downto 0);
        DDRDqsNxDIO        : inout std_logic_vector(3 downto 0);
        DDRDqsPxDIO        : inout std_logic_vector(3 downto 0);
        -- MIO Interface
        MIOxDIO            : inout std_logic_vector(53 downto 0);
        -----------------------------------------------------------------------
        -- USB signals
        UsbVbusPwrFaultxSI : in    std_logic;
        -- PLL interface
        Pll2V5ClkuWirexCO  : out   std_logic;  -- Clock (from SPI1_SCLK)
        Pll2V5DatauWirexSO : out   std_logic;  -- Data (from SPI1_MOSI)
        Pll2V5LEuWirexSO   : out   std_logic;  -- Latch enable (from SPI1_SS)
        Pll2V5GOExSO       : out   std_logic;  -- Global Output Enable
        Pll2V5LDxSI        : in    std_logic;  -- Lock Detect
        Pll2V5SyncxSO      : out   std_logic;  -- Sync
        Pll2V5ClkIn0LOSxSI : in    std_logic;  -- FPGA clock Loss of Sync
        Pll2V5ClkIn1LOSxSI : in    std_logic;  -- External oscillator Loss of Sync
        -- GTP interfaces
        -- Clocks
        GTPRefClk0PxCI     : in    std_logic;
        GTPRefClk0NxCI     : in    std_logic;
        GTPRefClk1PxCI     : in    std_logic;
        GTPRefClk1NxCI     : in    std_logic;
        -- North
        GTPFromNorthPxSI   : in    std_logic;
        GTPFromNorthNxSI   : in    std_logic;
        GTPToNorthPxSO     : out   std_logic;
        GTPToNorthNxSO     : out   std_logic;
        -- East
        GTPFromEastPxSI    : in    std_logic;
        GTPFromEastNxSI    : in    std_logic;
        GTPToEastPxSO      : out   std_logic;
        GTPToEastNxSO      : out   std_logic;
        -- South
        GTPFromSouthPxSI   : in    std_logic;
        GTPFromSouthNxSI   : in    std_logic;
        GTPToSouthPxSO     : out   std_logic;
        GTPToSouthNxSO     : out   std_logic;
        -- West
        GTPFromWestPxSI    : in    std_logic;
        GTPFromWestNxSI    : in    std_logic;
        GTPToWestPxSO      : out   std_logic;
        GTPToWestNxSO      : out   std_logic;
        -- LVDS links towards edge connectors
        -- North
        -- LVDS2V5North0PxSIO  : inout std_logic;
        -- LVDS2V5North0NxSIO  : inout std_logic;
        -- LVDS2V5North1PxSIO  : inout std_logic;
        -- LVDS2V5North1NxSIO  : inout std_logic;
        -- LVDS2V5North2PxSIO  : inout std_logic;
        -- LVDS2V5North2NxSIO  : inout std_logic;
        -- LVDS2V5North3PxSIO  : inout std_logic;
        -- LVDS2V5North3NxSIO  : inout std_logic;
        -- LVDS2V5North4PxSIO  : inout std_logic;
        -- LVDS2V5North4NxSIO  : inout std_logic;
        -- LVDS2V5North5PxSIO  : inout std_logic;
        -- LVDS2V5North5NxSIO  : inout std_logic;
        -- LVDS2V5North6PxSIO  : inout std_logic;
        -- LVDS2V5North6NxSIO  : inout std_logic;
        -- LVDS2V5North7PxSIO  : inout std_logic;
        -- LVDS2V5North7NxSIO  : inout std_logic;
        -- South
        -- LVDS2V5South0PxSIO  : inout std_logic;
        -- LVDS2V5South0NxSIO  : inout std_logic;
        -- LVDS2V5South1PxSIO  : inout std_logic;
        -- LVDS2V5South1NxSIO  : inout std_logic;
        -- LVDS2V5South2PxSIO  : inout std_logic;
        -- LVDS2V5South2NxSIO  : inout std_logic;
        -- LVDS2V5South3PxSIO  : inout std_logic;
        -- LVDS2V5South3NxSIO  : inout std_logic;
        -- LVDS2V5South4PxSIO  : inout std_logic;
        -- LVDS2V5South4NxSIO  : inout std_logic;
        -- LVDS2V5South5PxSIO  : inout std_logic;
        -- LVDS2V5South5NxSIO  : inout std_logic;
        -- LVDS2V5South6PxSIO  : inout std_logic;
        -- LVDS2V5South6NxSIO  : inout std_logic;
        -- LVDS2V5South7PxSIO  : inout std_logic;
        -- LVDS2V5South7NxSIO  : inout std_logic;
        -- East
        -- LVDS2V5East0PxSIO   : inout std_logic;
        -- LVDS2V5East0NxSIO   : inout std_logic;
        -- LVDS2V5East1PxSIO   : inout std_logic;
        -- LVDS2V5East1NxSIO   : inout std_logic;
        -- LVDS2V5East2PxSIO   : inout std_logic;
        -- LVDS2V5East2NxSIO   : inout std_logic;
        -- LVDS2V5East3PxSIO   : inout std_logic;
        -- LVDS2V5East3NxSIO   : inout std_logic;
        -- LVDS2V5East4PxSIO   : inout std_logic;
        -- LVDS2V5East4NxSIO   : inout std_logic;
        -- LVDS2V5East5PxSIO   : inout std_logic;
        -- LVDS2V5East5NxSIO   : inout std_logic;
        -- LVDS2V5East6PxSIO   : inout std_logic;
        -- LVDS2V5East6NxSIO   : inout std_logic;
        -- LVDS2V5East7PxSIO   : inout std_logic;
        -- LVDS2V5East7NxSIO   : inout std_logic;
        -- West
        -- LVDS2V5West0PxSIO   : inout std_logic;
        -- LVDS2V5West0NxSIO   : inout std_logic;
        -- LVDS2V5West1PxSIO   : inout std_logic;
        -- LVDS2V5West1NxSIO   : inout std_logic;
        -- LVDS2V5West2PxSIO   : inout std_logic;
        -- LVDS2V5West2NxSIO   : inout std_logic;
        -- LVDS2V5West3PxSIO   : inout std_logic;
        -- LVDS2V5West3NxSIO   : inout std_logic;
        -- LVDS2V5West4PxSIO   : inout std_logic;
        -- LVDS2V5West4NxSIO   : inout std_logic;
        -- LVDS2V5West5PxSIO   : inout std_logic;
        -- LVDS2V5West5NxSIO   : inout std_logic;
        -- LVDS2V5West6PxSIO   : inout std_logic;
        -- LVDS2V5West6NxSIO   : inout std_logic;
        -- LVDS2V5West7PxSIO   : inout std_logic;
        -- LVDS2V5West7NxSIO   : inout std_logic;
        -- LVDS links towards top-bottom connectors
        -- Top
        -- LVDS2V5Top0PxSIO    : inout std_logic;
        -- LVDS2V5Top0NxSIO    : inout std_logic;
        -- LVDS2V5Top1PxSIO    : inout std_logic;
        -- LVDS2V5Top1NxSIO    : inout std_logic;
        -- LVDS2V5Top2PxSIO    : inout std_logic;
        -- LVDS2V5Top2NxSIO    : inout std_logic;
        -- LVDS2V5Top3PxSIO    : inout std_logic;
        -- LVDS2V5Top3NxSIO    : inout std_logic;
        -- LVDS2V5Top4PxSIO    : inout std_logic;
        -- LVDS2V5Top4NxSIO    : inout std_logic;
        -- LVDS2V5Top5PxSIO    : inout std_logic;
        -- LVDS2V5Top5NxSIO    : inout std_logic;
        -- LVDS2V5Top6PxSIO    : inout std_logic;
        -- LVDS2V5Top6NxSIO    : inout std_logic;
        -- LVDS2V5Top7PxSIO    : inout std_logic;
        -- LVDS2V5Top7NxSIO    : inout std_logic;
        -- Bottom
        -- LVDS2V5Bottom0PxSIO : inout std_logic;
        -- LVDS2V5Bottom0NxSIO : inout std_logic;
        -- LVDS2V5Bottom1PxSIO : inout std_logic;
        -- LVDS2V5Bottom1NxSIO : inout std_logic;
        -- LVDS2V5Bottom2PxSIO : inout std_logic;
        -- LVDS2V5Bottom2NxSIO : inout std_logic;
        -- LVDS2V5Bottom3PxSIO : inout std_logic;
        -- LVDS2V5Bottom3NxSIO : inout std_logic;
        -- LVDS2V5Bottom4PxSIO : inout std_logic;
        -- LVDS2V5Bottom4NxSIO : inout std_logic;
        -- LVDS2V5Bottom5PxSIO : inout std_logic;
        -- LVDS2V5Bottom5NxSIO : inout std_logic;
        -- LVDS2V5Bottom6PxSIO : inout std_logic;
        -- LVDS2V5Bottom6NxSIO : inout std_logic;
        -- LVDS2V5Bottom7PxSIO : inout std_logic;
        -- LVDS2V5Bottom7NxSIO : inout std_logic;
        -- RGB LEDs
        Led12V5RxSO        : out   std_logic;
        Led12V5GxSO        : out   std_logic;
        Led12V5BxSO        : out   std_logic;
        Led22V5RxSO        : out   std_logic;
        Led22V5GxSO        : out   std_logic;
        Led22V5BxSO        : out   std_logic;
        -- Self reset (connected to PS_SRSTB)
        SelfRstxRNO        : out   std_logic);
    -- Clocks from PLLs (connected to MRCC pins)
    -- Local
    -- PLLClk2V5LocalPxCI  : in    std_logic;
    -- PLLClk2V5LocalNxCI  : in    std_logic;
    -- -- North
    -- PLLClk2V5NorthPxCI  : in    std_logic;
    -- PLLClk2V5NorthNxCI  : in    std_logic;
    -- -- South
    -- PLLClk2V5SouthPxCI  : in    std_logic;
    -- PLLClk2V5SouthNxCI  : in    std_logic;
    -- -- Top
    -- PLLClk2V5TopxCI     : in    std_logic;  -- Single-ended
    -- -- Bottom
    -- PLLClk2V5BottomxCI  : in    std_logic;  -- Single-ended
    -- -- Clocks to/from neighbours
    -- -- North
    -- Clk2V5NorthPxCI     : in    std_logic;
    -- Clk2V5NorthNxCI     : in    std_logic;
    -- Clk2V5NorthPxCO     : out   std_logic;
    -- Clk2V5NorthNxCO     : out   std_logic;
    -- -- South
    -- Clk2V5SouthPxCI     : in    std_logic;
    -- Clk2V5SouthNxCI     : in    std_logic;
    -- Clk2V5SouthPxCO     : out   std_logic;
    -- Clk2V5SouthNxCO     : out   std_logic;
    -- -- East
    -- Clk2V5EastPxCI      : in    std_logic;
    -- Clk2V5EastNxCI      : in    std_logic;
    -- Clk2V5EastPxCO      : out   std_logic;
    -- Clk2V5EastNxCO      : out   std_logic;
    -- -- West
    -- Clk2V5WestPxCI      : in    std_logic;
    -- Clk2V5WestNxCI      : in    std_logic;
    -- Clk2V5WestPxCO      : out   std_logic;
    -- Clk2V5WestNxCO      : out   std_logic;
    -- -- Top
    -- Clk2V5TopPxCI       : in    std_logic;
    -- Clk2V5TopNxCI       : in    std_logic;
    -- Clk2V5TopPxCO       : out   std_logic;
    -- Clk2V5TopNxCO       : out   std_logic;
    -- -- Bottom
    -- Clk2V5BottomPxCI    : in    std_logic;
    -- Clk2V5BottomNxCI    : in    std_logic;
    -- Clk2V5BottomPxCO    : out   std_logic;
    -- Clk2V5BottomNxCO    : out   std_logic;
    -- -- Recovery
    -- Clk2V5RecoveryPxCO  : out   std_logic;
    -- Clk2V5RecoveryNxCO  : out   std_logic);

end scalp_firmware;


architecture arch of scalp_firmware is

    -- Constantes
    -- constant C_PS_SYS_RESET_SIZE : integer range 0 to 7 := 1;
    constant C_AXI_ADDR_SIZE : integer range 0 to 32 := 12;

    component scalp_aurora_phy is
        generic (
            C_DEBUG_MODE : boolean);
        port (
            GTRefClkxCI      : in  t_gt_ref_slave_clk;
            AuroraClkxCI     : in  t_aurora_slave_clk;
            AuroraClkxCO     : out t_aurora_master_clk;
            AuroraResetxRI   : in  t_aurora_slave_reset;
            AuroraResetxRO   : out t_aurora_master_link_reset;
            GTPFromNorthxDI  : in  t_aurora_gtp_diff_io_rx;
            GTPToNorthxDO    : out t_aurora_gtp_diff_io_tx;
            GTPFromEastxDI   : in  t_aurora_gtp_diff_io_rx;
            GTPToEastxDO     : out t_aurora_gtp_diff_io_tx;
            GTPFromSouthxDI  : in  t_aurora_gtp_diff_io_rx;
            GTPToSouthxDO    : out t_aurora_gtp_diff_io_tx;
            GTPFromWestxDI   : in  t_aurora_gtp_diff_io_rx;
            GTPToWestxDO     : out t_aurora_gtp_diff_io_tx;
            NorthRXM2SxDO    : out t_axi4m2s;
            NorthTXM2SxDI    : in  t_axi4m2s;
            NorthTXS2MxDO    : out t_axi4s2m;
            EastRXM2SxDO     : out t_axi4m2s;
            EastTXM2SxDI     : in  t_axi4m2s;
            EastTXS2MxDO     : out t_axi4s2m;
            SouthRXM2SxDO    : out t_axi4m2s;
            SouthTXM2SxDI    : in  t_axi4m2s;
            SouthTXS2MxDO    : out t_axi4s2m;
            WestRXM2SxDO     : out t_axi4m2s;
            WestTXM2SxDI     : in  t_axi4m2s;
            WestTXS2MxDO     : out t_axi4s2m;
            NorthRXUFCM2SxDO : out t_axi4ufcm2s_rx;
            NorthTXUFCM2SxDI : in  t_axi4ufcm2s_tx;
            NorthTXUFCS2MxDO : out t_axi4ufcs2m_tx;
            EastRXUFCM2SxDO  : out t_axi4ufcm2s_rx;
            EastTXUFCM2SxDI  : in  t_axi4ufcm2s_tx;
            EastTXUFCS2MxDO  : out t_axi4ufcs2m_tx;
            SouthRXUFCM2SxDO : out t_axi4ufcm2s_rx;
            SouthTXUFCM2SxDI : in  t_axi4ufcm2s_tx;
            SouthTXUFCS2MxDO : out t_axi4ufcs2m_tx;
            WestRXUFCM2SxDO  : out t_axi4ufcm2s_rx;
            WestTXUFCM2SxDI  : in  t_axi4ufcm2s_tx;
            WestTXUFCS2MxDO  : out t_axi4ufcs2m_tx;
            NorthRXNFCM2SxDO : out t_axi4nfcm2s;
            NorthTXNFCM2SxDI : in  t_axi4nfcm2s;
            NorthTXNFCS2MxDO : out t_axi4nfcs2m;
            EastRXNFCM2SxDO  : out t_axi4nfcm2s;
            EastTXNFCM2SxDI  : in  t_axi4nfcm2s;
            EastTXNFCS2MxDO  : out t_axi4nfcs2m;
            SouthRXNFCM2SxDO : out t_axi4nfcm2s;
            SouthTXNFCM2SxDI : in  t_axi4nfcm2s;
            SouthTXNFCS2mxDO : out t_axi4nfcs2m;
            WestRXNFCM2SxDO  : out t_axi4nfcm2s;
            WestTXNFCM2SxDI  : in  t_axi4nfcm2s;
            WestTXNFCS2MxDO  : out t_axi4nfcs2m;
            AuroraCtrlxDI    : in  t_aurora_control;
            AuroraStatusxDO  : out t_aurora_status;
            AuroraDRPM2SxDI  : in  t_drpm2s_vector((C_NB_GTP_CORE - 1) downto 0);
            AuroraDRPS2MxDO  : out t_drps2m_vector((C_NB_GTP_CORE - 1) downto 0));
    end component scalp_aurora_phy;

    -- Signals
    -- Clocks
    -- Processing system clock
    signal PSSysClkxC                    : std_logic                                          := '0';
    -- GTP Clocks
    -- signal GTPRefClk0xC : std_logic := '0';
    -- signal GTPRefClk1xC : std_logic := '0';
    signal GTRefClk0DiffxC               : t_gtp_diff_ref_clk                                 := C_NO_GTP_DIFF_REF_CLK;
    signal GTRefClk1DiffxC               : t_gtp_diff_ref_clk                                 := C_NO_GTP_DIFF_REF_CLK;
    -- Resets
    -- Processing system reset
    signal PSSysResetxR                  : std_logic                                          := '0';
    -- Scalp Aurora Phy
    signal GTRefClk0xC                   : t_gt_ref_slave_clk                                 := C_GT_REF_NO_SLAVE_CLK;
    signal GTRefClk1xC                   : t_gt_ref_slave_clk                                 := C_GT_REF_NO_SLAVE_CLK;
    signal AuroraClkSlavexC              : t_aurora_slave_clk                                 := C_AURORA_NO_SLAVE_CLK;
    signal AuroraClkMasterxC             : t_aurora_master_clk                                := C_AURORA_NO_MASTER_CLK;
    signal AuroraResetSlavexR            : t_aurora_slave_reset                               := C_AURORA_NO_SLAVE_RESET;
    signal AuroraResetMasterLinkxR       : t_aurora_master_link_reset                         := C_AURORA_NO_MASTER_LINK_RESET;
    signal GTPFromNorthxD                : t_aurora_gtp_diff_io_rx                            := C_AURORA_NO_GTP_DIFF_IO_RX;
    signal GTPToNorthxD                  : t_aurora_gtp_diff_io_tx                            := C_AURORA_NO_GTP_DIFF_IO_TX;
    signal GTPFromEastxD                 : t_aurora_gtp_diff_io_rx                            := C_AURORA_NO_GTP_DIFF_IO_RX;
    signal GTPToEastxD                   : t_aurora_gtp_diff_io_tx                            := C_AURORA_NO_GTP_DIFF_IO_TX;
    signal GTPFromSouthxD                : t_aurora_gtp_diff_io_rx                            := C_AURORA_NO_GTP_DIFF_IO_RX;
    signal GTPToSouthxD                  : t_aurora_gtp_diff_io_tx                            := C_AURORA_NO_GTP_DIFF_IO_TX;
    signal GTPFromWestxD                 : t_aurora_gtp_diff_io_rx                            := C_AURORA_NO_GTP_DIFF_IO_RX;
    signal GTPToWestxD                   : t_aurora_gtp_diff_io_tx                            := C_AURORA_NO_GTP_DIFF_IO_TX;
    signal NorthRXM2SxD                  : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal NorthTXM2SxD                  : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal NorthTXS2MxD                  : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal EastRXM2SxD                   : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal EastTXM2SxD                   : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal EastTXS2MxD                   : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal SouthRXM2SxD                  : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal SouthTXM2SxD                  : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal SouthTXS2MxD                  : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal WestRXM2SxD                   : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal WestTXM2SxD                   : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal WestTXS2MxD                   : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal NorthRXfromPhyTXfromFifoM2SxD : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal NorthRXfromPhyTXfromFifoS2MxD : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal EastRXfromPhyTXfromFifoM2SxD  : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal EastRXfromPhyTXfromFifoS2MxD  : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal SouthRXfromPhyTXfromFifoM2SxD : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal SouthRXfromPhyTXfromFifoS2MxD : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal WestRXfromPhyTXfromFifoM2SxD  : t_axi4m2s                                          := C_NO_AXI4_M2S;
    signal WestRXfromPhyTXfromFifoS2MxD  : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal NorthRXFromFifoS2MxD          : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal EastRXFromFifoS2MxD           : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal SouthRXFromFifoS2MxD          : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal WestRXFromFifoS2MxD           : t_axi4s2m                                          := C_NO_AXI4_S2M;
    signal NorthRXUFCM2SxD               : t_axi4ufcm2s_rx                                    := C_NO_AXI4_UFC_M2S_RX;
    signal NorthTXUFCM2SxD               : t_axi4ufcm2s_tx                                    := C_NO_AXI4_UFC_M2S_TX;
    signal NorthTXUFCS2MxD               : t_axi4ufcs2m_tx                                    := C_NO_AXI4_UFC_S2M_TX;
    signal EastRXUFCM2SxD                : t_axi4ufcm2s_rx                                    := C_NO_AXI4_UFC_M2S_RX;
    signal EastTXUFCM2SxD                : t_axi4ufcm2s_tx                                    := C_NO_AXI4_UFC_M2S_TX;
    signal EastTXUFCS2MxD                : t_axi4ufcs2m_tx                                    := C_NO_AXI4_UFC_S2M_TX;
    signal SouthRXUFCM2SxD               : t_axi4ufcm2s_rx                                    := C_NO_AXI4_UFC_M2S_RX;
    signal SouthTXUFCM2SxD               : t_axi4ufcm2s_tx                                    := C_NO_AXI4_UFC_M2S_TX;
    signal SouthTXUFCS2MxD               : t_axi4ufcs2m_tx                                    := C_NO_AXI4_UFC_S2M_TX;
    signal WestRXUFCM2SxD                : t_axi4ufcm2s_rx                                    := C_NO_AXI4_UFC_M2S_RX;
    signal WestTXUFCM2SxD                : t_axi4ufcm2s_tx                                    := C_NO_AXI4_UFC_M2S_TX;
    signal WestTXUFCS2MxD                : t_axi4ufcs2m_tx                                    := C_NO_AXI4_UFC_S2M_TX;
    signal NorthRXNFCM2SxD               : t_axi4nfcm2s                                       := C_NO_AXI4_NFC_M2S;
    signal NorthTXNFCM2SxD               : t_axi4nfcm2s                                       := C_NO_AXI4_NFC_M2S;
    signal NorthTXNFCS2MxD               : t_axi4nfcs2m                                       := C_NO_AXI4_NFC_S2M;
    signal EastRXNFCM2SxD                : t_axi4nfcm2s                                       := C_NO_AXI4_NFC_M2S;
    signal EastTXNFCM2SxD                : t_axi4nfcm2s                                       := C_NO_AXI4_NFC_M2S;
    signal EastTXNFCS2MxD                : t_axi4nfcs2m                                       := C_NO_AXI4_NFC_S2M;
    signal SouthRXNFCM2SxD               : t_axi4nfcm2s                                       := C_NO_AXI4_NFC_M2S;
    signal SouthTXNFCM2SxD               : t_axi4nfcm2s                                       := C_NO_AXI4_NFC_M2S;
    signal SouthTXNFCS2MxD               : t_axi4nfcs2m                                       := C_NO_AXI4_NFC_S2M;
    signal WestRXNFCM2SxD                : t_axi4nfcm2s                                       := C_NO_AXI4_NFC_M2S;
    signal WestTXNFCM2SxD                : t_axi4nfcm2s                                       := C_NO_AXI4_NFC_M2S;
    signal WestTXNFCS2MxD                : t_axi4nfcs2m                                       := C_NO_AXI4_NFC_S2M;
    signal AuroraCtrlxD                  : t_aurora_control                                   := C_AURORA_NO_CONTROL;
    signal AuroraStatusxD                : t_aurora_status                                    := C_AURORA_NO_STATUS;
    signal AuroraDRPM2SxD                : t_drpm2s_vector((C_NB_GTP_CORE - 1) downto 0)      := (others => C_NO_DRP_M2S);
    signal AuroraDRPS2MxD                : t_drps2m_vector((C_NB_GTP_CORE - 1) downto 0)      := (others => C_NO_DRP_S2M);
    signal NorthFifoStatusxD             : t_axi4fifo_status                                  := C_NO_AXI4_FIFO_STATUS;
    signal EastFifoStatusxD              : t_axi4fifo_status                                  := C_NO_AXI4_FIFO_STATUS;
    signal SouthFifoStatusxD             : t_axi4fifo_status                                  := C_NO_AXI4_FIFO_STATUS;
    signal WestFifoStatusxD              : t_axi4fifo_status                                  := C_NO_AXI4_FIFO_STATUS;
    -- Scalp Axi Lite interface and IRQ
    signal InterruptxS                   : std_ulogic                                         := '0';
    signal RdAddrxD                      : std_ulogic_vector((C_AXI_ADDR_SIZE - 1) downto 0)  := (others => '0');
    signal RdDataxD                      : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal RdValidxS                     : std_ulogic                                         := '0';
    signal WrAddrxD                      : std_ulogic_vector((C_AXI_ADDR_SIZE - 1) downto 0)  := (others => '0');
    signal WrDataxD                      : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal WrValidxS                     : std_ulogic                                         := '0';
    -- Zynq Reg Bank
    type t_status_send_word is (E_IDLE, E_SEND);

    signal NorthStatusSendWordxDN   : t_status_send_word                                 := E_IDLE;
    signal NorthStatusSendWordxDP   : t_status_send_word                                 := E_IDLE;
    signal EastStatusSendWordxDN    : t_status_send_word                                 := E_IDLE;
    signal EastStatusSendWordxDP    : t_status_send_word                                 := E_IDLE;
    signal SouthStatusSendWordxDN   : t_status_send_word                                 := E_IDLE;
    signal SouthStatusSendWordxDP   : t_status_send_word                                 := E_IDLE;
    signal WestStatusSendWordxDN    : t_status_send_word                                 := E_IDLE;
    signal WestStatusSendWordxDP    : t_status_send_word                                 := E_IDLE;
    --
    signal NorthNativeSlavexD       : t_native_fifo_slave;
    signal NorthNativeMasterxD      : t_native_fifo_master;
    signal EastNativeSlavexD        : t_native_fifo_slave;
    signal EastNativeMasterxD       : t_native_fifo_master;
    signal SouthNativeSlavexD       : t_native_fifo_slave;
    signal SouthNativeMasterxD      : t_native_fifo_master;
    signal WestNativeSlavexD        : t_native_fifo_slave;
    signal WestNativeMasterxD       : t_native_fifo_master;
    --
    -- signal InterruptRegPortxDN    : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    -- signal InterruptRegPortxDP    : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    -- North
    signal NorthStatusRegPortxDN    : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal NorthStatusRegPortxDP    : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal NorthCtrlRegPortxDN      : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal NorthCtrlRegPortxDP      : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal NorthWrDataRegPortxDN    : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal NorthWrDataRegPortxDP    : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    -- East
    signal EastStatusRegPortxDN     : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal EastStatusRegPortxDP     : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal EastCtrlRegPortxDN       : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal EastCtrlRegPortxDP       : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal EastWrDataRegPortxDN     : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal EastWrDataRegPortxDP     : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    -- South
    signal SouthStatusRegPortxDN    : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal SouthStatusRegPortxDP    : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal SouthCtrlRegPortxDN      : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal SouthCtrlRegPortxDP      : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal SouthWrDataRegPortxDN    : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal SouthWrDataRegPortxDP    : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    -- West
    signal WestStatusRegPortxDN     : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal WestStatusRegPortxDP     : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal WestCtrlRegPortxDN       : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal WestCtrlRegPortxDP       : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal WestWrDataRegPortxDN     : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    signal WestWrDataRegPortxDP     : std_ulogic_vector((C_AXI4_DATA_SIZE - 1) downto 0) := (others => '0');
    -- Debug
    -- signal CntRstxR               : std_ulogic                                         := '0';
    signal ClkEnxS                  : std_ulogic                                         := '0';
    signal DataCounterxD            : std_ulogic_vector(31 downto 0)                     := (others => '0');
    --
    signal DebugCounterResetxR      : std_ulogic                                         := '0';
    signal DebugRXFifoResetxR       : std_ulogic                                         := '0';
    signal DebugBackPressureResetxR : std_ulogic                                         := '0';

    -- Attributes
    attribute mark_debug                      : string;
    attribute keep                            : string;
    -- Clocks
    attribute keep of PSSysClkxC              : signal is "true";
    attribute keep of GTRefClk0xC             : signal is "true";
    attribute keep of GTRefClk1xC             : signal is "true";
    attribute keep of AuroraClkSlavexC        : signal is "true";
    attribute keep of AuroraClkMasterxC       : signal is "true";
    -- Resets
    -- attribute mark_debug of PSSysResetxR                  : signal is "true";
    -- attribute keep of PSSysResetxR                        : signal is "true";
    -- attribute mark_debug of AuroraResetSlavexR            : signal is "true";
    -- attribute keep of AuroraResetSlavexR                  : signal is "true";
    -- attribute mark_debug of AuroraResetMasterLinkxR       : signal is "true";
    -- attribute keep of AuroraResetMasterLinkxR             : signal is "true";
    -- Aurora
    attribute mark_debug of NorthFifoStatusxD : signal is "true";
    attribute keep of NorthFifoStatusxD       : signal is "true";
    attribute mark_debug of EastFifoStatusxD  : signal is "true";
    attribute keep of EastFifoStatusxD        : signal is "true";
    attribute mark_debug of SouthFifoStatusxD : signal is "true";
    attribute keep of SouthFifoStatusxD       : signal is "true";
    attribute mark_debug of WestFifoStatusxD  : signal is "true";
    attribute keep of WestFifoStatusxD        : signal is "true";
    -- attribute mark_debug of NorthRXM2SxD                  : signal is "true";
    -- attribute keep of NorthRXM2SxD                        : signal is "true";
    -- attribute mark_debug of NorthRXFromFifoS2MxD          : signal is "true";
    -- attribute keep of NorthRXFromFifoS2MxD                : signal is "true";
    -- attribute mark_debug of NorthRXfromPhyTXfromFifoM2SxD : signal is "true";
    -- attribute keep of NorthRXfromPhyTXfromFifoM2SxD       : signal is "true";
    -- attribute mark_debug of NorthRXfromPhyTXfromFifoS2MxD : signal is "true";
    -- attribute keep of NorthRXfromPhyTXfromFifoS2MxD       : signal is "true";
    -- attribute mark_debug of EastFifoStatusxD              : signal is "true";
    -- attribute keep of EastFifoStatusxD                    : signal is "true";
    -- attribute mark_debug of EastRXM2SxD                   : signal is "true";
    -- attribute keep of EastRXM2SxD                         : signal is "true";
    -- attribute mark_debug of EastRXFromFifoS2MxD           : signal is "true";
    -- attribute keep of EastRXFromFifoS2MxD                 : signal is "true";
    -- attribute mark_debug of EastRXfromPhyTXfromFifoM2SxD  : signal is "true";
    -- attribute keep of EastRXfromPhyTXfromFifoM2SxD        : signal is "true";
    -- attribute mark_debug of EastRXfromPhyTXfromFifoS2MxD  : signal is "true";
    -- attribute keep of EastRXfromPhyTXfromFifoS2MxD        : signal is "true";
    -- attribute mark_debug of SouthFifoStatusxD             : signal is "true";
    -- attribute keep of SouthFifoStatusxD                   : signal is "true";
    -- attribute mark_debug of SouthRXM2SxD                  : signal is "true";
    -- attribute keep of SouthRXM2SxD                        : signal is "true";
    -- attribute mark_debug of SouthRXFromFifoS2MxD          : signal is "true";
    -- attribute keep of SouthRXFromFifoS2MxD                : signal is "true";
    -- attribute mark_debug of SouthRXfromPhyTXfromFifoM2SxD : signal is "true";
    -- attribute keep of SouthRXfromPhyTXfromFifoM2SxD       : signal is "true";
    -- attribute mark_debug of SouthRXfromPhyTXfromFifoS2MxD : signal is "true";
    -- attribute keep of SouthRXfromPhyTXfromFifoS2MxD       : signal is "true";
    -- attribute mark_debug of WestFifoStatusxD              : signal is "true";
    -- attribute keep of WestFifoStatusxD                    : signal is "true";
    -- attribute mark_debug of WestRXM2SxD                   : signal is "true";
    -- attribute keep of WestRXM2SxD                         : signal is "true";
    -- attribute mark_debug of WestRXFromFifoS2MxD           : signal is "true";
    -- attribute keep of WestRXFromFifoS2MxD                 : signal is "true";
    -- attribute mark_debug of WestRXfromPhyTXfromFifoM2SxD  : signal is "true";
    -- attribute keep of WestRXfromPhyTXfromFifoM2SxD        : signal is "true";
    -- attribute mark_debug of WestRXfromPhyTXfromFifoS2MxD  : signal is "true";
    -- attribute keep of WestRXfromPhyTXfromFifoS2MxD        : signal is "true";
    --
    attribute mark_debug of NorthRXM2SxD      : signal is "true";
    attribute keep of NorthRXM2SxD            : signal is "true";
    attribute mark_debug of NorthTXM2SxD      : signal is "true";
    attribute keep of NorthTXM2SxD            : signal is "true";
    attribute mark_debug of NorthTXS2MxD      : signal is "true";
    attribute keep of NorthTXS2MxD            : signal is "true";
    attribute mark_debug of EastRXM2SxD       : signal is "true";
    attribute keep of EastRXM2SxD             : signal is "true";
    attribute mark_debug of EastTXM2SxD       : signal is "true";
    attribute keep of EastTXM2SxD             : signal is "true";
    attribute mark_debug of EastTXS2MxD       : signal is "true";
    attribute keep of EastTXS2MxD             : signal is "true";
    attribute mark_debug of SouthRXM2SxD      : signal is "true";
    attribute keep of SouthRXM2SxD            : signal is "true";
    attribute mark_debug of SouthTXM2SxD      : signal is "true";
    attribute keep of SouthTXM2SxD            : signal is "true";
    attribute mark_debug of SouthTXS2MxD      : signal is "true";
    attribute keep of SouthTXS2MxD            : signal is "true";
    attribute mark_debug of WestRXM2SxD       : signal is "true";
    attribute keep of WestRXM2SxD             : signal is "true";
    attribute mark_debug of WestTXM2SxD       : signal is "true";
    attribute keep of WestTXM2SxD             : signal is "true";
    attribute mark_debug of WestTXS2MxD       : signal is "true";
    attribute keep of WestTXS2MxD             : signal is "true";
    attribute mark_debug of NorthRXNFCM2SxD   : signal is "true";
    attribute keep of NorthRXNFCM2SxD         : signal is "true";
    attribute mark_debug of NorthTXNFCM2SxD   : signal is "true";
    attribute keep of NorthTXNFCM2SxD         : signal is "true";
    attribute mark_debug of NorthTXNFCS2MxD   : signal is "true";
    attribute keep of NorthTXNFCS2MxD         : signal is "true";
    attribute mark_debug of EastRXNFCM2SxD    : signal is "true";
    attribute keep of EastRXNFCM2SxD          : signal is "true";
    attribute mark_debug of EastTXNFCM2SxD    : signal is "true";
    attribute keep of EastTXNFCM2SxD          : signal is "true";
    attribute mark_debug of EastTXNFCS2MxD    : signal is "true";
    attribute keep of EastTXNFCS2MxD          : signal is "true";
    attribute mark_debug of SouthRXNFCM2SxD   : signal is "true";
    attribute keep of SouthRXNFCM2SxD         : signal is "true";
    attribute mark_debug of SouthTXNFCM2SxD   : signal is "true";
    attribute keep of SouthTXNFCM2SxD         : signal is "true";
    attribute mark_debug of SouthTXNFCS2mxD   : signal is "true";
    attribute keep of SouthTXNFCS2mxD         : signal is "true";
    attribute mark_debug of WestRXNFCM2SxD    : signal is "true";
    attribute keep of WestRXNFCM2SxD          : signal is "true";
    attribute mark_debug of WestTXNFCM2SxD    : signal is "true";
    attribute keep of WestTXNFCM2SxD          : signal is "true";
    attribute mark_debug of WestTXNFCS2MxD    : signal is "true";
    attribute keep of WestTXNFCS2MxD          : signal is "true";
    attribute mark_debug of AuroraCtrlxD      : signal is "true";
    attribute keep of AuroraCtrlxD            : signal is "true";
    attribute mark_debug of AuroraStatusxD    : signal is "true";
    attribute keep of AuroraStatusxD          : signal is "true";
    -- attribute mark_debug of NorthTXM2SxD                  : signal is "true";
    -- attribute keep of NorthTXM2SxD                        : signal is "true";
    -- attribute mark_debug of EastTXM2SxD                   : signal is "true";
    -- attribute keep of EastTXM2SxD                         : signal is "true";
    -- attribute mark_debug of SouthTXM2SxD                  : signal is "true";
    -- attribute keep of SouthTXM2SxD                        : signal is "true";
    -- attribute mark_debug of WestTXM2SxD                   : signal is "true";
    -- attribute keep of WestTXM2SxD                         : signal is "true";

begin

    ProcessingSystemxB : block is
    begin  -- block ProcessingSystemxB

        ZynqxI : entity work.scalp_zynqps_wrapper
            port map (
                -- Processor interface
                FIXED_IO_ps_clk     => PSClkxCIO,
                FIXED_IO_ps_porb    => PSPorxSNIO,
                FIXED_IO_ps_srstb   => PSSRstxRNIO,
                FclkClk0xCO         => PSSysClkxC,
                FclkReset0xRO       => PSSysResetxR,
                -- DDR interface
                DDR_addr            => DDRAddrxDIO,
                DDR_ba              => DDRBankAddrxDIO,
                DDR_cas_n           => DDRCasNxSIO,
                DDR_ck_n            => DDRClkNxCIO,
                DDR_ck_p            => DDRClkPxCIO,
                DDR_cke             => DDRCkexSIO,
                DDR_cs_n            => DDRCsNxSIO,
                DDR_dm              => DDRDmxDIO,
                DDR_dq              => DDRDqxDIO,
                DDR_dqs_n           => DDRDqsNxDIO,
                DDR_dqs_p           => DDRDqsPxDIO,
                DDR_odt             => DDROdtxSIO,
                DDR_ras_n           => DDRRasNxSIO,
                DDR_reset_n         => DDRDRstxRNIO,
                DDR_we_n            => DDRWexSNIO,
                FIXED_IO_ddr_vrn    => DDRVrNxSIO,
                FIXED_IO_ddr_vrp    => DDRVrPxSIO,
                -- USB interface
                Usb0VBusPwrFaultxSI => UsbVbusPwrFaultxSI,
                -- SPI1 used as uWire master. Clk, Data and LE signals are outputs
                -- SPI1 inputs are unused. Clk is connected to SCLK, Data to MOSI and LE to SS
                Spi1MOSIxSO         => Pll2V5DatauWirexSO,
                Spi1SSxSO           => Pll2V5LEuWirexSO,
                Spi1SclkxCO         => Pll2V5ClkuWirexCO,
                -- MIO
                FIXED_IO_mio        => MIOxDIO,
                -- Scalp Axi Lite interface and IRQ
                InterruptxSI        => InterruptxS,
                RdAddrxDO           => RdAddrxD,
                RdDataxDI           => RdDataxD,
                RdValidxSO          => RdValidxS,
                WrAddrxDO           => WrAddrxD,
                WrDataxDO           => WrDataxD,
                WrValidxSO          => WrValidxS);

    end block ProcessingSystemxB;

    ProgrammableLogicxB : block is
    begin  -- block ProgrammableLogicxB        

        InputClocksxB : block is
        begin  -- block InputClocksxB

            GTPRefClk0PxAS : GTRefClk0DiffxC.ClkPxC <= GTPRefClk0PxCI;
            GTPRefClk0NxAS : GTRefClk0DiffxC.ClkNxC <= GTPRefClk0NxCI;
            -- GTPRefClk1PxAS : GTRefClk0DiffxC.ClkPxC <= GTPRefClk1PxCI;
            -- GTPRefClk1NxAS : GTRefClk0DiffxC.ClkNxC <= GTPRefClk1NxCI;

            -- GTP Clocks buffers
            IBufDSGTPRefClk0xI : IBUFDS_GTE2
                port map (
                    I     => GTRefClk0DiffxC.ClkPxC,
                    IB    => GTRefClk0DiffxC.ClkNxC,
                    CEB   => '0',
                    O     => GTRefClk0xC.GTRefClkxC,
                    ODIV2 => open);

            -- IBufDSGTPRefClk1xI : IBUFDS_GTE2
            --     port map (
            --         I     => GTRefClk0DiffxC.ClkPxC,
            --         IB    => GTRefClk0DiffxC.ClkNxC,
            --         CEB   => '0',
            --         O     => GTRefClk1xCGTRefClkxC,
            --         ODIV2 => open);

        end block InputClocksxB;

        PllClocksxB : block is

            constant C_AURORA_RST_DLY_TICKS : integer := 25;
            constant C_GT_RST_DLY_TICKS     : integer := 625;

            signal PllLockedxS : std_ulogic := '0';

        begin  -- block PllClocksxB

            ScalpAuroraPllxI : entity work.scalp_aurora_clk
                port map (
                    -- Clock out ports  
                    InitClkxCO   => AuroraClkSlavexC.InitClkxC,
                    DrpClkxCO    => AuroraClkSlavexC.DrpClkxC,
                    -- Status and control signals                
                    reset        => PSSysResetxR,
                    PllLockedxSO => PllLockedxS,
                    -- Clock in ports
                    PSSysClkxCI  => PSSysClkxC);

            AuroraRstDlyxI : entity work.reset_delay_gen
                generic map (
                    C_TICKS => C_AURORA_RST_DLY_TICKS)
                port map (
                    ClkxCI          => AuroraClkSlavexC.InitClkxC,
                    PllLockedxSI    => PllLockedxS,
                    ResetxRI        => PSSysResetxR,
                    ResetDelayedxRO => AuroraResetSlavexR.ResetxR);

            GTRstDlyxI : entity work.reset_delay_gen
                generic map (
                    C_TICKS => C_GT_RST_DLY_TICKS)
                port map (
                    ClkxCI          => AuroraClkSlavexC.InitClkxC,
                    PllLockedxSI    => PllLockedxS,
                    ResetxRI        => PSSysResetxR,
                    ResetDelayedxRO => AuroraResetSlavexR.GTResetxR);

        end block PllClocksxB;

        GTPhyxB : block is
        begin  -- block GTPhyxB

            -- GTP
            GTPFromNorthPxAS : GTPFromNorthxD.RXPxD(0) <= GTPFromNorthPxSI;
            GTPFromNorthNxAS : GTPFromNorthxD.RXNxD(0) <= GTPFromNorthNxSI;
            GTPToNorthPxAS   : GTPToNorthPxSO          <= GTPToNorthxD.TXPxD(0);
            GTPToNorthNxAS   : GTPToNorthNxSO          <= GTPToNorthxD.TXNxD(0);
            GTPFromEastPxAS  : GTPFromEastxD.RXPxD(0)  <= GTPFromEastPxSI;
            GTPFromEastNxAS  : GTPFromEastxD.RXNxD(0)  <= GTPFromEastNxSI;
            GTPToEastPxAS    : GTPToEastPxSO           <= GTPToEastxD.TXPxD(0);
            GTPToEastNxAS    : GTPToEastNxSO           <= GTPToEastxD.TXNxD(0);
            GTPFromSouthPxAS : GTPFromSouthxD.RXPxD(0) <= GTPFromSouthPxSI;
            GTPFromSouthNxAS : GTPFromSouthxD.RXNxD(0) <= GTPFromSouthNxSI;
            GTPToSouthPxAS   : GTPToSouthPxSO          <= GTPToSouthxD.TXPxD(0);
            GTPToSouthNxAS   : GTPToSouthNxSO          <= GTPToSouthxD.TXNxD(0);
            GTPFromWestPxAS  : GTPFromWestxD.RXPxD(0)  <= GTPFromWestPxSI;
            GTPFromWestNxAS  : GTPFromWestxD.RXNxD(0)  <= GTPFromWestNxSI;
            GTPToWestPxAS    : GTPToWestPxSO           <= GTPToWestxD.TXPxD(0);
            GTPToWestNxAS    : GTPToWestNxSO           <= GTPToWestxD.TXNxD(0);

            CtrlxB : block is
            begin  -- block CtrlxB

                PowerDownxAS : AuroraCtrlxD.PowerDownxS <= '0';
                LoopbackxAS  : AuroraCtrlxD.LoopbackxD  <= (others => '0');

            end block CtrlxB;

            ScalpAuroraPyhxI : entity work.scalp_aurora_phy
                generic map (
                    C_DEBUG_MODE => C_DEBUG_MODE)
                port map (
                    -- GTP Ref Clocks
                    GTRefClkxCI      => GTRefClk0xC,
                    -- Aurora System and GTP Clocks
                    AuroraClkxCI     => AuroraClkSlavexC,
                    AuroraClkxCO     => AuroraClkMasterxC,
                    -- Aurora Reset
                    AuroraResetxRI   => AuroraResetSlavexR,
                    AuroraResetxRO   => AuroraResetMasterLinkxR,
                    -- GTP Serial IO
                    -- North
                    GTPFromNorthxDI  => GTPFromNorthxD,
                    GTPToNorthxDO    => GTPToNorthxD,
                    -- East
                    GTPFromEastxDI   => GTPFromEastxD,
                    GTPToEastxDO     => GTPToEastxD,
                    -- South
                    GTPFromSouthxDI  => GTPFromSouthxD,
                    GTPToSouthxDO    => GTPToSouthxD,
                    -- West
                    GTPFromWestxDI   => GTPFromWestxD,
                    GTPToWestxDO     => GTPToWestxD,
                    -- Axi4 Framing Interface
                    -- North
                    NorthRXM2SxDO    => NorthRXM2SxD,
                    NorthTXM2SxDI    => NorthTXM2SxD,
                    NorthTXS2MxDO    => NorthTXS2MxD,
                    -- East
                    EastRXM2SxDO     => EastRXM2SxD,
                    EastTXM2SxDI     => EastTXM2SxD,
                    EastTXS2MxDO     => EastTXS2MxD,
                    -- South
                    SouthRXM2SxDO    => SouthRXM2SxD,
                    SouthTXM2SxDI    => SouthTXM2SxD,
                    SouthTXS2MxDO    => SouthTXS2MxD,
                    -- West
                    WestRXM2SxDO     => WestRXM2SxD,
                    WestTXM2SxDI     => WestTXM2SxD,
                    WestTXS2MxDO     => WestTXS2MxD,
                    -- Axi4 Framing UFC Interface
                    -- North
                    NorthRXUFCM2SxDO => NorthRXUFCM2SxD,
                    NorthTXUFCM2SxDI => NorthTXUFCM2SxD,
                    NorthTXUFCS2MxDO => NorthTXUFCS2MxD,
                    -- East
                    EastRXUFCM2SxDO  => EastRXUFCM2SxD,
                    EastTXUFCM2SxDI  => EastTXUFCM2SxD,
                    EastTXUFCS2MxDO  => EastTXUFCS2MxD,
                    -- South
                    SouthRXUFCM2SxDO => SouthRXUFCM2SxD,
                    SouthTXUFCM2SxDI => SouthTXUFCM2SxD,
                    SouthTXUFCS2MxDO => SouthTXUFCS2MxD,
                    -- West
                    WestRXUFCM2SxDO  => WestRXUFCM2SxD,
                    WestTXUFCM2SxDI  => WestTXUFCM2SxD,
                    WestTXUFCS2MxDO  => WestTXUFCS2MxD,
                    -- Axi4 Framing NFC Interface
                    -- North
                    NorthRXNFCM2SxDO => NorthRXNFCM2SxD,
                    NorthTXNFCM2SxDI => NorthTXNFCM2SxD,
                    NorthTXNFCS2MxDO => NorthTXNFCS2MxD,
                    -- East
                    EastRXNFCM2SxDO  => EastRXNFCM2SxD,
                    EastTXNFCM2SxDI  => EastTXNFCM2SxD,
                    EastTXNFCS2MxDO  => EastTXNFCS2MxD,
                    -- South
                    SouthRXNFCM2SxDO => SouthRXNFCM2SxD,
                    SouthTXNFCM2SxDI => SouthTXNFCM2SxD,
                    SouthTXNFCS2mxDO => SouthTXNFCS2mxD,
                    -- West
                    WestRXNFCM2SxDO  => WestRXNFCM2SxD,
                    WestTXNFCM2SxDI  => WestTXNFCM2SxD,
                    WestTXNFCS2MxDO  => WestTXNFCS2MxD,
                    -- Aurora Ctrl + Status
                    AuroraCtrlxDI    => AuroraCtrlxD,
                    AuroraStatusxDO  => AuroraStatusxD,
                    -- DRP Port
                    AuroraDRPM2SxDI  => (others => C_NO_DRP_M2S),
                    AuroraDRPS2MxDO  => open);

            RXFifoxB : block is

                signal RXFifoRstxRAN : std_ulogic := '0';

            begin  -- block RXFifoxB

                RXFifoRstxAS : RXFifoRstxRAN <= (not AuroraClkMasterxC.PllNotLockedxS) and (not DebugRXFifoResetxR);

                ScalpAuroraPhyRXFifoxI : entity work.scalp_aurora_phy_rx_fifo
                    port map (
                        -- Clocks and reset
                        RXClkxCI           => AuroraClkMasterxC.UserClkxC,
                        TXClkxCI           => AuroraClkMasterxC.UserClkxC,
                        RXRstxRANI         => RXFifoRstxRAN,
                        -- North
                        -- Fifo RX Side
                        NorthRXM2SxDI      => NorthRXM2SxD,
                        NorthRXS2MxDO      => NorthRXFromFifoS2MxD,
                        -- Fifo TX Side
                        NorthTXM2SxDO      => NorthRXfromPhyTXfromFifoM2SxD,
                        NorthTXS2MxDI      => NorthRXfromPhyTXfromFifoS2MxD,
                        NorthFifoStatusxDO => NorthFifoStatusxD,
                        -- East
                        -- Fifo RX Side
                        EastRXM2SxDI       => EastRXM2SxD,
                        EastRXS2MxDO       => EastRXFromFifoS2MxD,
                        -- Fifo TX Side
                        EastTXM2SxDO       => EastRXfromPhyTXfromFifoM2SxD,
                        EastTXS2MxDI       => EastRXfromPhyTXfromFifoS2MxD,
                        EastFifoStatusxDO  => EastFifoStatusxD,
                        -- South
                        -- Fifo RX Side
                        SouthRXM2SxDI      => SouthRXM2SxD,
                        SouthRXS2MxDO      => SouthRXFromFifoS2MxD,
                        -- Fifo TX Side
                        SouthTXM2SxDO      => SouthRXfromPhyTXfromFifoM2SxD,
                        SouthTXS2MxDI      => SouthRXfromPhyTXfromFifoS2MxD,
                        SouthFifoStatusxDO => SouthFifoStatusxD,
                        -- West
                        -- Fifo RX Side
                        WestRXM2SxDI       => WestRXM2SxD,
                        WestRXS2MxDO       => WestRXFromFifoS2MxD,
                        -- Fifo TX Side
                        WestTXM2SxDO       => WestRXfromPhyTXfromFifoM2SxD,
                        WestTXS2MxDI       => WestRXfromPhyTXfromFifoS2MxD,
                        WestFifoStatusxDO  => WestFifoStatusxD);

            end block RXFifoxB;

            BackPressurexB : block is

                signal BackPressureResetxR : std_ulogic                                             := '0';
                -- North
                signal NorthProgFullxSN    : std_ulogic                                             := '0';
                signal NorthProgFullxSP    : std_ulogic                                             := '0';
                signal NorthProgEmptyxSN   : std_ulogic                                             := '0';
                signal NorthProgEmptyxSP   : std_ulogic                                             := '0';
                signal NorthNFCStatexDN    : t_nfc_states                                           := C_NFC_IDLE;
                signal NorthNFCStatexDP    : t_nfc_states                                           := C_NFC_IDLE;
                signal NorthNFCDataxDN     : std_ulogic_vector((C_AXI4_NFC_DATA_SIZE - 1) downto 0) := (others => '0');
                signal NorthNFCDataxDP     : std_ulogic_vector((C_AXI4_NFC_DATA_SIZE - 1) downto 0) := (others => '0');
                signal NorthNFCValidxSN    : std_ulogic                                             := '0';
                signal NorthNFCValidxSP    : std_ulogic                                             := '0';
                -- East
                signal EastProgFullxSN     : std_ulogic                                             := '0';
                signal EastProgFullxSP     : std_ulogic                                             := '0';
                signal EastProgEmptyxSN    : std_ulogic                                             := '0';
                signal EastProgEmptyxSP    : std_ulogic                                             := '0';
                signal EastNFCStatexDN     : t_nfc_states                                           := C_NFC_IDLE;
                signal EastNFCStatexDP     : t_nfc_states                                           := C_NFC_IDLE;
                signal EastNFCDataxDN      : std_ulogic_vector((C_AXI4_NFC_DATA_SIZE - 1) downto 0) := (others => '0');
                signal EastNFCDataxDP      : std_ulogic_vector((C_AXI4_NFC_DATA_SIZE - 1) downto 0) := (others => '0');
                signal EastNFCValidxSN     : std_ulogic                                             := '0';
                signal EastNFCValidxSP     : std_ulogic                                             := '0';
                -- South
                signal SouthProgFullxSN    : std_ulogic                                             := '0';
                signal SouthProgFullxSP    : std_ulogic                                             := '0';
                signal SouthProgEmptyxSN   : std_ulogic                                             := '0';
                signal SouthProgEmptyxSP   : std_ulogic                                             := '0';
                signal SouthNFCStatexDN    : t_nfc_states                                           := C_NFC_IDLE;
                signal SouthNFCStatexDP    : t_nfc_states                                           := C_NFC_IDLE;
                signal SouthNFCDataxDN     : std_ulogic_vector((C_AXI4_NFC_DATA_SIZE - 1) downto 0) := (others => '0');
                signal SouthNFCDataxDP     : std_ulogic_vector((C_AXI4_NFC_DATA_SIZE - 1) downto 0) := (others => '0');
                signal SouthNFCValidxSN    : std_ulogic                                             := '0';
                signal SouthNFCValidxSP    : std_ulogic                                             := '0';
                -- West
                signal WestProgFullxSN     : std_ulogic                                             := '0';
                signal WestProgFullxSP     : std_ulogic                                             := '0';
                signal WestProgEmptyxSN    : std_ulogic                                             := '0';
                signal WestProgEmptyxSP    : std_ulogic                                             := '0';
                signal WestNFCStatexDN     : t_nfc_states                                           := C_NFC_IDLE;
                signal WestNFCStatexDP     : t_nfc_states                                           := C_NFC_IDLE;
                signal WestNFCDataxDN      : std_ulogic_vector((C_AXI4_NFC_DATA_SIZE - 1) downto 0) := (others => '0');
                signal WestNFCDataxDP      : std_ulogic_vector((C_AXI4_NFC_DATA_SIZE - 1) downto 0) := (others => '0');
                signal WestNFCValidxSN     : std_ulogic                                             := '0';
                signal WestNFCValidxSP     : std_ulogic                                             := '0';

                -- Attributes
                attribute mark_debug                        : string;
                attribute keep                              : string;
                --
                attribute mark_debug of BackPressureResetxR : signal is "true";
                attribute keep of BackPressureResetxR       : signal is "true";
                --
                attribute mark_debug of NorthNFCStatexDP    : signal is "true";
                attribute keep of NorthNFCStatexDP          : signal is "true";
                attribute mark_debug of NorthNFCDataxDP     : signal is "true";
                attribute keep of NorthNFCDataxDP           : signal is "true";
                attribute mark_debug of NorthNFCValidxSP    : signal is "true";
                attribute keep of NorthNFCValidxSP          : signal is "true";
                --
                attribute mark_debug of EastNFCStatexDP     : signal is "true";
                attribute keep of EastNFCStatexDP           : signal is "true";
                attribute mark_debug of EastNFCDataxDP      : signal is "true";
                attribute keep of EastNFCDataxDP            : signal is "true";
                attribute mark_debug of EastNFCValidxSP     : signal is "true";
                attribute keep of EastNFCValidxSP           : signal is "true";
                --
                attribute mark_debug of SouthNFCStatexDP    : signal is "true";
                attribute keep of SouthNFCStatexDP          : signal is "true";
                attribute mark_debug of SouthNFCDataxDP     : signal is "true";
                attribute keep of SouthNFCDataxDP           : signal is "true";
                attribute mark_debug of SouthNFCValidxSP    : signal is "true";
                attribute keep of SouthNFCValidxSP          : signal is "true";
                --
                attribute mark_debug of WestNFCStatexDP     : signal is "true";
                attribute keep of WestNFCStatexDP           : signal is "true";
                attribute mark_debug of WestNFCDataxDP      : signal is "true";
                attribute keep of WestNFCDataxDP            : signal is "true";
                attribute mark_debug of WestNFCValidxSP     : signal is "true";
                attribute keep of WestNFCValidxSP           : signal is "true";

            begin  -- block BackPressurexB

                BackPressureResetxAS : BackPressureResetxR <= AuroraClkMasterxC.PllNotLockedxS or
                                                              DebugBackPressureResetxR;
                -- NFC Data and valid signals
                NorthNFCDataxAS   : NorthTXNFCM2SxD.DataxD  <= NorthNFCDataxDP;
                NorthNFCValidxAS  : NorthTXNFCM2SxD.ValidxS <= NorthNFCValidxSP;
                NorthProgFullxAS  : NorthProgFullxSN        <= NorthFifoStatusxD.ProgFullxS;
                NorthProgEmptyxAS : NorthProgEmptyxSN       <= NorthFifoStatusxD.ProgEmptyxS;
                EastNFCDataxAS    : EastTXNFCM2SxD.DataxD   <= EastNFCDataxDP;
                EastNFCValidxAS   : EastTXNFCM2SxD.ValidxS  <= EastNFCValidxSP;
                SouthNFCDataxAS   : SouthTXNFCM2SxD.DataxD  <= SouthNFCDataxDP;
                SouthNFCValidxAS  : SouthTXNFCM2SxD.ValidxS <= SouthNFCValidxSP;
                WestNFCDataxAS    : WestTXNFCM2SxD.DataxD   <= WestNFCDataxDP;
                WestNFCValidxAS   : WestTXNFCM2SxD.ValidxS  <= WestNFCValidxSP;

                UpdateRegxP : process (AuroraClkMasterxC.UserClkxC,
                                       BackPressureResetxR) is
                begin  -- process UpdateRegxP
                    if BackPressureResetxR = '1' then
                        NorthProgFullxSP  <= '0';
                        NorthProgEmptyxSP <= '0';
                        NorthNFCStatexDP  <= C_NFC_IDLE;
                        NorthNFCDataxDP   <= (others => '0');
                        NorthNFCValidxSP  <= '0';
                        EastProgFullxSP   <= '0';
                        EastProgEmptyxSP  <= '0';
                        EastNFCStatexDP   <= C_NFC_IDLE;
                        EastNFCDataxDP    <= (others => '0');
                        EastNFCValidxSP   <= '0';
                        SouthProgFullxSP  <= '0';
                        SouthProgEmptyxSP <= '0';
                        SouthNFCStatexDP  <= C_NFC_IDLE;
                        SouthNFCDataxDP   <= (others => '0');
                        SouthNFCValidxSP  <= '0';
                        WestProgFullxSP   <= '0';
                        WestProgEmptyxSP  <= '0';
                        WestNFCStatexDP   <= C_NFC_IDLE;
                        WestNFCDataxDP    <= (others => '0');
                        WestNFCValidxSP   <= '0';
                    elsif rising_edge(AuroraClkMasterxC.UserClkxC) then
                        NorthProgFullxSP  <= NorthProgFullxSN;
                        NorthProgEmptyxSP <= NorthProgEmptyxSN;
                        NorthNFCStatexDP  <= NorthNFCStatexDN;
                        NorthNFCDataxDP   <= NorthNFCDataxDN;
                        NorthNFCValidxSP  <= NorthNFCValidxSN;
                        EastProgFullxSP   <= EastProgFullxSN;
                        EastProgEmptyxSP  <= EastProgEmptyxSN;
                        EastNFCStatexDP   <= EastNFCStatexDN;
                        EastNFCDataxDP    <= EastNFCDataxDN;
                        EastNFCValidxSP   <= EastNFCValidxSN;
                        SouthProgFullxSP  <= SouthProgFullxSN;
                        SouthProgEmptyxSP <= SouthProgEmptyxSN;
                        SouthNFCStatexDP  <= SouthNFCStatexDN;
                        SouthNFCDataxDP   <= SouthNFCDataxDN;
                        SouthNFCValidxSP  <= SouthNFCValidxSN;
                        WestProgFullxSP   <= WestProgFullxSN;
                        WestProgEmptyxSP  <= WestProgEmptyxSN;
                        WestNFCStatexDP   <= WestNFCStatexDN;
                        WestNFCDataxDP    <= WestNFCDataxDN;
                        WestNFCValidxSP   <= WestNFCValidxSN;
                    end if;
                end process UpdateRegxP;

                NorthNFCStatexP : process (NorthNFCDataxDP, NorthNFCStatexDP,
                                           NorthNFCValidxSP, NorthProgEmptyxSN,
                                           NorthProgEmptyxSP, NorthProgFullxSN,
                                           NorthProgFullxSP,
                                           NorthTXNFCS2MxD.ReadyxS) is
                begin  -- process NorthNFCStatexP
                    -- Default values
                    NorthNFCStatexDN <= NorthNFCStatexDP;
                    NorthNFCDataxDN  <= NorthNFCDataxDP;
                    NorthNFCValidxSN <= NorthNFCValidxSP;

                    case NorthNFCStatexDP is
                        when C_NFC_IDLE =>
                                NorthNFCStatexDN <= C_NFC_IS_XON;
                        when C_NFC_IS_XON =>
                                if NorthProgFullxSP = '0' and NorthProgFullxSN = '1' then  --or
                                    --(NorthRXFromFifoS2MxD.ReadyxS = '0') then
                                    NorthNFCDataxDN  <= C_NFC_XOFF;
                                    NorthNFCValidxSN <= '1';
                                    NorthNFCStatexDN <= C_NFC_SEND_XOFF;
                                end if;

                        when C_NFC_IS_XOFF =>
                                if NorthProgEmptyxSP = '0' and NorthProgEmptyxSN = '1' then  -- and
                                    --(NorthRXFromFifoS2MxD.ReadyxS = '1') then
                                    NorthNFCDataxDN  <= C_NFC_XON;
                                    NorthNFCValidxSN <= '1';
                                    NorthNFCStatexDN <= C_NFC_SEND_XON;
                                end if;

                        when C_NFC_SEND_XON =>
                                if NorthTXNFCS2MxD.ReadyxS = '1' then
                                    NorthNFCValidxSN <= '0';
                                    NorthNFCStatexDN <= C_NFC_IS_XON;
                                end if;

                        when C_NFC_SEND_XOFF =>
                                if NorthTXNFCS2MxD.ReadyxS = '1' then
                                    NorthNFCValidxSN <= '0';
                                    NorthNFCStatexDN <= C_NFC_IS_XOFF;
                                end if;

                        when others => null;
                    end case;

                end process NorthNFCStatexP;

                EastNFCStatexP : process (EastNFCDataxDP, EastNFCStatexDP,
                                          EastNFCValidxSP, EastProgEmptyxSN,
                                          EastProgEmptyxSP, EastProgFullxSN,
                                          EastProgFullxSP,
                                          EastTXNFCS2MxD.ReadyxS) is
                begin  -- process EastNFCStatexP
                    -- Default values
                    EastNFCStatexDN <= EastNFCStatexDP;
                    EastNFCDataxDN  <= EastNFCDataxDP;
                    EastNFCValidxSN <= EastNFCValidxSP;

                    case EastNFCStatexDP is
                        when C_NFC_IDLE =>
                                EastNFCStatexDN <= C_NFC_IS_XON;
                        when C_NFC_IS_XON =>
                                if EastProgFullxSP = '0' and EastProgFullxSN = '1' then  --or
                                    --(EastRXFromFifoS2MxD.ReadyxS = '0') then
                                    EastNFCDataxDN  <= C_NFC_XOFF;
                                    EastNFCValidxSN <= '1';
                                    EastNFCStatexDN <= C_NFC_SEND_XOFF;
                                end if;

                        when C_NFC_IS_XOFF =>
                                if EastProgEmptyxSP = '0' and EastProgEmptyxSN = '1' then  -- and
                                    --(EastRXFromFifoS2MxD.ReadyxS = '1') then
                                    EastNFCDataxDN  <= C_NFC_XON;
                                    EastNFCValidxSN <= '1';
                                    EastNFCStatexDN <= C_NFC_SEND_XON;
                                end if;

                        when C_NFC_SEND_XON =>
                                if EastTXNFCS2MxD.ReadyxS = '1' then
                                    EastNFCValidxSN <= '0';
                                    EastNFCStatexDN <= C_NFC_IS_XON;
                                end if;

                        when C_NFC_SEND_XOFF =>
                                if EastTXNFCS2MxD.ReadyxS = '1' then
                                    EastNFCValidxSN <= '0';
                                    EastNFCStatexDN <= C_NFC_IS_XOFF;
                                end if;

                        when others => null;
                    end case;

                end process EastNFCStatexP;

                SouthNFCStatexP : process (SouthNFCDataxDP, SouthNFCStatexDP,
                                           SouthNFCValidxSP, SouthProgEmptyxSN,
                                           SouthProgEmptyxSP, SouthProgFullxSN,
                                           SouthProgFullxSP,
                                           SouthTXNFCS2MxD.ReadyxS) is
                begin  -- process SouthNFCStatexP
                    -- Default values
                    SouthNFCStatexDN <= SouthNFCStatexDP;
                    SouthNFCDataxDN  <= SouthNFCDataxDP;
                    SouthNFCValidxSN <= SouthNFCValidxSP;

                    case SouthNFCStatexDP is
                        when C_NFC_IDLE =>
                                SouthNFCStatexDN <= C_NFC_IS_XON;
                        when C_NFC_IS_XON =>
                                if SouthProgFullxSP = '0' and SouthProgFullxSN = '1' then  -- or
                                    --(SouthRXFromFifoS2MxD.ReadyxS = '0') then
                                    SouthNFCDataxDN  <= C_NFC_XOFF;
                                    SouthNFCValidxSN <= '1';
                                    SouthNFCStatexDN <= C_NFC_SEND_XOFF;
                                end if;

                        when C_NFC_IS_XOFF =>
                                if SouthProgEmptyxSP = '0' and SouthProgEmptyxSN = '1' then  -- and
                                    --(SouthRXFromFifoS2MxD.ReadyxS = '1') then
                                    SouthNFCDataxDN  <= C_NFC_XON;
                                    SouthNFCValidxSN <= '1';
                                    SouthNFCStatexDN <= C_NFC_SEND_XON;
                                end if;

                        when C_NFC_SEND_XON =>
                                if SouthTXNFCS2MxD.ReadyxS = '1' then
                                    SouthNFCValidxSN <= '0';
                                    SouthNFCStatexDN <= C_NFC_IS_XON;
                                end if;

                        when C_NFC_SEND_XOFF =>
                                if SouthTXNFCS2MxD.ReadyxS = '1' then
                                    SouthNFCValidxSN <= '0';
                                    SouthNFCStatexDN <= C_NFC_IS_XOFF;
                                end if;

                        when others => null;
                    end case;

                end process SouthNFCStatexP;

                WestNFCStatexP : process (WestNFCDataxDP, WestNFCStatexDP,
                                          WestNFCValidxSP, WestProgEmptyxSN,
                                          WestProgEmptyxSP, WestProgFullxSN,
                                          WestProgFullxSP,
                                          WestTXNFCS2MxD.ReadyxS) is
                begin  -- process WestNFCStatexP
                    -- Default values
                    WestNFCStatexDN <= WestNFCStatexDP;
                    WestNFCDataxDN  <= WestNFCDataxDP;
                    WestNFCValidxSN <= WestNFCValidxSP;

                    case WestNFCStatexDP is
                        when C_NFC_IDLE =>
                                WestNFCStatexDN <= C_NFC_IS_XON;
                        when C_NFC_IS_XON =>
                                if WestProgFullxSP = '0' and WestProgFullxSN = '1' then  --or
                                    --(WestRXFromFifoS2MxD.ReadyxS = '0') then
                                    WestNFCDataxDN  <= C_NFC_XOFF;
                                    WestNFCValidxSN <= '1';
                                    WestNFCStatexDN <= C_NFC_SEND_XOFF;
                                end if;

                        when C_NFC_IS_XOFF =>
                                if WestProgEmptyxSP = '0' and WestProgEmptyxSN = '1' then  -- and
                                    --(WestRXFromFifoS2MxD.ReadyxS = '1') then
                                    WestNFCDataxDN  <= C_NFC_XON;
                                    WestNFCValidxSN <= '1';
                                    WestNFCStatexDN <= C_NFC_SEND_XON;
                                end if;

                        when C_NFC_SEND_XON =>
                                if WestTXNFCS2MxD.ReadyxS = '1' then
                                    WestNFCValidxSN <= '0';
                                    WestNFCStatexDN <= C_NFC_IS_XON;
                                end if;

                        when C_NFC_SEND_XOFF =>
                                if WestTXNFCS2MxD.ReadyxS = '1' then
                                    WestNFCValidxSN <= '0';
                                    WestNFCStatexDN <= C_NFC_IS_XOFF;
                                end if;

                        when others => null;
                    end case;

                end process WestNFCStatexP;

            end block BackPressurexB;

        end block GTPhyxB;

        -- ZynqRegBankxB : block is
        -- begin  -- block ZynqRegBankxB


        --     RegBankxB : block is
        --     begin  -- block RegBankxB

        --         WriteRegPortxP : process (EastCtrlRegPortxDP,
        --                                   EastWrDataRegPortxDP,
        --                                   NorthCtrlRegPortxDP,
        --                                   NorthWrDataRegPortxDP,
        --                                   SouthCtrlRegPortxDP,
        --                                   SouthWrDataRegPortxDP,
        --                                   WestCtrlRegPortxDP,
        --                                   WestWrDataRegPortxDP, WrAddrxD,
        --                                   WrDataxD, WrValidxS) is
        --         begin  -- process WriteRegPortxP
        --             -- North                    
        --             NorthCtrlRegPortxDN   <= NorthCtrlRegPortxDP;
        --             NorthWrDataRegPortxDN <= NorthWrDataRegPortxDP;
        --             -- East
        --             EastCtrlRegPortxDN    <= EastCtrlRegPortxDP;
        --             EastWrDataRegPortxDN  <= EastWrDataRegPortxDP;
        --             -- South
        --             SouthCtrlRegPortxDN   <= SouthCtrlRegPortxDP;
        --             SouthWrDataRegPortxDN <= SouthWrDataRegPortxDP;
        --             -- West
        --             WestCtrlRegPortxDN    <= WestCtrlRegPortxDP;
        --             WestWrDataRegPortxDN  <= WestWrDataRegPortxDP;

        --             if WrValidxS = '1' then
        --                 case WrAddrxD is
        --                     -- Ctrl
        --                     -- North
        --                     when x"000" => NorthCtrlRegPortxDN   <= WrDataxD;
        --                     when x"004" => NorthCtrlRegPortxDN   <= NorthCtrlRegPortxDP or WrDataxD;
        --                     when x"008" => NorthCtrlRegPortxDN   <= NorthCtrlRegPortxDP and not WrDataxD;
        --                     -- East
        --                     when x"00c" => EastCtrlRegPortxDN    <= WrDataxD;
        --                     when x"010" => EastCtrlRegPortxDN    <= EastCtrlRegPortxDP or WrDataxD;
        --                     when x"014" => EastCtrlRegPortxDN    <= EastCtrlRegPortxDP and not WrDataxD;
        --                     -- South
        --                     when x"018" => SouthCtrlRegPortxDN   <= WrDataxD;
        --                     when x"01c" => SouthCtrlRegPortxDN   <= SouthCtrlRegPortxDP or WrDataxD;
        --                     when x"020" => SouthCtrlRegPortxDN   <= SouthCtrlRegPortxDP and not WrDataxD;
        --                     -- East
        --                     when x"024" => WestCtrlRegPortxDN    <= WrDataxD;
        --                     when x"028" => WestCtrlRegPortxDN    <= WestCtrlRegPortxDP or WrDataxD;
        --                     when x"02c" => WestCtrlRegPortxDN    <= WestCtrlRegPortxDP and not WrDataxD;
        --                     -- Data
        --                     -- North
        --                     when x"030" => NorthWrDataRegPortxDN <= WrDataxD;
        --                     -- East
        --                     when x"034" => EastWrDataRegPortxDN  <= WrDataxD;
        --                     -- South
        --                     when x"038" => SouthWrDataRegPortxDN <= WrDataxD;
        --                     -- West
        --                     when x"03c" => WestWrDataRegPortxDN  <= WrDataxD;
        --                     when others => null;
        --                 end case;
        --             end if;
        --         end process WriteRegPortxP;

        --         ReadRegPortxP : process (PSSysClkxC, PSSysResetxR) is
        --         begin  -- process ReadRegPortxP
        --             if PSSysResetxR = '1' then
        --                 RdDataxD <= (others => '0');
        --             elsif rising_edge(PSSysClkxC) then
        --                 RdDataxD <= (others => '0');

        --                 if RdValidxS = '1' then
        --                     case RdAddrxD is
        --                         when x"000" => RdDataxD <= NorthCtrlRegPortxDP;
        --                         when x"00C" => RdDataxD <= EastCtrlRegPortxDP;
        --                         when x"018" => RdDataxD <= SouthCtrlRegPortxDP;
        --                         when x"024" => RdDataxD <= WestCtrlRegPortxDP;
        --                         when x"030" => RdDataxD <= NorthWrDataRegPortxDP;
        --                         when x"034" => RdDataxD <= EastWrDataRegPortxDP;
        --                         when x"038" => RdDataxD <= SouthWrDataRegPortxDP;
        --                         when x"03c" => RdDataxD <= WestWrDataRegPortxDP;
        --                         when x"040" => RdDataxD <= NorthStatusRegPortxDP;
        --                         when x"044" => RdDataxD <= EastStatusRegPortxDP;
        --                         when x"048" => RdDataxD <= SouthStatusRegPortxDP;
        --                         when x"04c" => RdDataxD <= WestStatusRegPortxDP;
        --                         when others => RdDataxD <= (others => '0');
        --                     end case;
        --                 end if;
        --             end if;
        --         end process ReadRegPortxP;

        --         RegBankxP : process (PSSysClkxC, PSSysResetxR) is
        --         begin  -- process RegBankxP
        --             if PSSysResetxR = '1' then
        --                 -- North
        --                 NorthStatusRegPortxDP <= (others => '0');
        --                 NorthCtrlRegPortxDP   <= (others => '0');
        --                 NorthWrDataRegPortxDP <= (others => '0');
        --                 -- East
        --                 EastStatusRegPortxDP  <= (others => '0');
        --                 EastCtrlRegPortxDP    <= (others => '0');
        --                 EastWrDataRegPortxDP  <= (others => '0');
        --                 -- South
        --                 SouthStatusRegPortxDP <= (others => '0');
        --                 SouthCtrlRegPortxDP   <= (others => '0');
        --                 SouthWrDataRegPortxDP <= (others => '0');
        --                 -- West
        --                 WestStatusRegPortxDP  <= (others => '0');
        --                 WestCtrlRegPortxDP    <= (others => '0');
        --                 WestWrDataRegPortxDP  <= (others => '0');
        --             elsif rising_edge(PSSysClkxC) then
        --                 -- North
        --                 NorthStatusRegPortxDP <= NorthStatusRegPortxDN;
        --                 NorthCtrlRegPortxDP   <= NorthCtrlRegPortxDN;
        --                 NorthWrDataRegPortxDP <= NorthWrDataRegPortxDN;
        --                 -- East
        --                 EastStatusRegPortxDP  <= EastStatusRegPortxDN;
        --                 EastCtrlRegPortxDP    <= EastCtrlRegPortxDN;
        --                 EastWrDataRegPortxDP  <= EastWrDataRegPortxDN;
        --                 -- South
        --                 SouthStatusRegPortxDP <= SouthStatusRegPortxDN;
        --                 SouthCtrlRegPortxDP   <= SouthCtrlRegPortxDN;
        --                 SouthWrDataRegPortxDP <= SouthWrDataRegPortxDN;
        --                 -- West
        --                 WestStatusRegPortxDP  <= WestStatusRegPortxDN;
        --                 WestCtrlRegPortxDP    <= WestCtrlRegPortxDN;
        --                 WestWrDataRegPortxDP  <= WestWrDataRegPortxDN;
        --             end if;
        --         end process RegBankxP;

        --     end block RegBankxB;

        --     TxFifoxB : block is
        --     begin  -- block TxFifoxB

        --         NorthWrDataxAS   : NorthNativeSlavexD.DataxD <= NorthWrDataRegPortxDP;
        --         EastWrDataxAS    : EastNativeSlavexD.DataxD  <= EastWrDataRegPortxDP;
        --         SouthWrDataxAS   : SouthNativeSlavexD.DataxD <= SouthWrDataRegPortxDN;
        --         WestWrDataRegxAS : WestNativeSlavexD.DataxD  <= WestWrDataRegPortxDN;
        --         NorthWrEnxAS     : NorthNativeSlavexD.WrEnxS <= NorthCtrlRegPortxDP(0);
        --         EastWrEnxAS      : EastNativeSlavexD.WrEnxS  <= EastCtrlRegPortxDP(0);
        --         SouthWrEnxAS     : SouthNativeSlavexD.WrEnxS <= SouthCtrlRegPortxDP(0);
        --         WestWrEnxAS      : EastNativeSlavexD.WrEnxS  <= EastCtrlRegPortxDP(0);
        --         NorthStatusRegPortxAS : NorthStatusRegPortxDN <= (0      => NorthNativeMasterxD.FullxS,
        --                                                           1      => NorthNativeMasterxD.EmptyxS,
        --                                                           2      => NorthNativeMasterxD.AlmostFullxS,
        --                                                           3      => NorthNativeMasterxD.AlmostEmptyxS,
        --                                                           4      => NorthNativeMasterxD.WrRstBusyxS,
        --                                                           5      => NorthNativeMasterxD.RdRstBusyxS,
        --                                                           others => '0');
        --         EastStatusRegPortxAS : EastStatusRegPortxDN <= (0      => EastNativeMasterxD.FullxS,
        --                                                         1      => EastNativeMasterxD.EmptyxS,
        --                                                         2      => EastNativeMasterxD.AlmostFullxS,
        --                                                         3      => EastNativeMasterxD.AlmostEmptyxS,
        --                                                         4      => EastNativeMasterxD.WrRstBusyxS,
        --                                                         5      => EastNativeMasterxD.RdRstBusyxS,
        --                                                         others => '0');
        --         SouthStatusRegPortxAS : SouthStatusRegPortxDN <= (0      => SouthNativeMasterxD.FullxS,
        --                                                           1      => SouthNativeMasterxD.EmptyxS,
        --                                                           2      => SouthNativeMasterxD.AlmostFullxS,
        --                                                           3      => SouthNativeMasterxD.AlmostEmptyxS,
        --                                                           4      => SouthNativeMasterxD.WrRstBusyxS,
        --                                                           5      => SouthNativeMasterxD.RdRstBusyxS,
        --                                                           others => '0');
        --         WestStatusRegPortxAS : WestStatusRegPortxDN <= (0      => WestNativeMasterxD.FullxS,
        --                                                         1      => WestNativeMasterxD.EmptyxS,
        --                                                         2      => WestNativeMasterxD.AlmostFullxS,
        --                                                         3      => WestNativeMasterxD.AlmostEmptyxS,
        --                                                         4      => WestNativeMasterxD.WrRstBusyxS,
        --                                                         5      => WestNativeMasterxD.RdRstBusyxS,
        --                                                         others => '0');

        --         UpdateRegxP : process (AuroraClkMasterxC.PllNotLockedxS,
        --                                AuroraClkMasterxC.UserClkxC) is
        --         begin  -- process UpdateRegxP
        --             if not AuroraClkMasterxC.PllNotLockedxS then
        --                 NorthStatusSendWordxDP <= E_IDLE;
        --                 EastStatusSendWordxDP  <= E_IDLE;
        --                 SouthStatusSendWordxDP <= E_IDLE;
        --                 WestStatusSendWordxDP  <= E_IDLE;
        --             elsif rising_edge(AuroraClkMasterxC.UserClkxC) then
        --                 NorthStatusSendWordxDP <= NorthStatusSendWordxDN;
        --                 EastStatusSendWordxDP  <= EastStatusSendWordxDN;
        --                 SouthStatusSendWordxDP <= SouthStatusSendWordxDN;
        --                 WestStatusSendWordxDP  <= WestStatusSendWordxDN;
        --             end if;
        --         end process UpdateRegxP;

        --         NorthSendWordxP : process (NorthNativeMasterxD.DataxD,
        --                                    NorthNativeMasterxD.EmptyxS,
        --                                    NorthStatusSendWordxDP,
        --                                    NorthTXS2MxD.ReadyxS) is
        --         begin  -- process NorthSendWordxP
        --             NorthTXM2SxD.DataxD       <= (others => '0');
        --             NorthTXM2SxD.KeepxD       <= (others => '1');
        --             NorthTXM2SxD.LastxS       <= '0';
        --             NorthTXM2SxD.ValidxS      <= '0';
        --             NorthNativeSlavexD.RdEnxS <= '0';
        --             NorthStatusSendWordxDN    <= NorthStatusSendWordxDP;

        --             case NorthStatusSendWordxDP is
        --                 when E_IDLE =>

        --                         if (NorthNativeMasterxD.EmptyxS = '0') and
        --                             (NorthTXS2MxD.ReadyxS = '1') then
        --                             NorthTXM2SxD.DataxD       <= NorthNativeMasterxD.DataxD;
        --                             NorthTXM2SxD.LastxS       <= '1';
        --                             NorthTXM2SxD.ValidxS      <= '1';
        --                             NorthNativeSlavexD.RdEnxS <= '1';
        --                             NorthStatusSendWordxDN    <= E_SEND;
        --                         end if;

        --                 when E_SEND =>
        --                         NorthStatusSendWordxDN <= E_IDLE;

        --                 when others => null;
        --             end case;
        --         end process NorthSendWordxP;

        --         EastSendWordxP : process (EastNativeMasterxD.DataxD,
        --                                   EastNativeMasterxD.EmptyxS,
        --                                   EastStatusSendWordxDP,
        --                                   EastTXS2MxD.ReadyxS) is
        --         begin  -- process EastSendWordxP
        --             EastTXM2SxD.DataxD       <= (others => '0');
        --             EastTXM2SxD.KeepxD       <= (others => '1');
        --             EastTXM2SxD.LastxS       <= '0';
        --             EastTXM2SxD.ValidxS      <= '0';
        --             EastNativeSlavexD.RdEnxS <= '0';
        --             EastStatusSendWordxDN    <= EastStatusSendWordxDP;

        --             case EastStatusSendWordxDP is
        --                 when E_IDLE =>

        --                         if (EastNativeMasterxD.EmptyxS = '0') and
        --                             (EastTXS2MxD.ReadyxS = '1') then
        --                             EastTXM2SxD.DataxD       <= EastNativeMasterxD.DataxD;
        --                             EastTXM2SxD.LastxS       <= '1';
        --                             EastTXM2SxD.ValidxS      <= '1';
        --                             EastNativeSlavexD.RdEnxS <= '1';
        --                             EastStatusSendWordxDN    <= E_SEND;
        --                         end if;

        --                 when E_SEND =>
        --                         EastStatusSendWordxDN <= E_IDLE;

        --                 when others => null;
        --             end case;
        --         end process EastSendWordxP;

        --         SouthSendWordxP : process (SouthNativeMasterxD.DataxD,
        --                                    SouthNativeMasterxD.EmptyxS,
        --                                    SouthStatusSendWordxDP,
        --                                    SouthTXS2MxD.ReadyxS) is
        --         begin  -- process SouthSendWordxP
        --             SouthTXM2SxD.DataxD       <= (others => '0');
        --             SouthTXM2SxD.KeepxD       <= (others => '1');
        --             SouthTXM2SxD.LastxS       <= '0';
        --             SouthTXM2SxD.ValidxS      <= '0';
        --             SouthNativeSlavexD.RdEnxS <= '0';
        --             SouthStatusSendWordxDN    <= SouthStatusSendWordxDP;

        --             case SouthStatusSendWordxDP is
        --                 when E_IDLE =>

        --                         if (SouthNativeMasterxD.EmptyxS = '0') and
        --                             (SouthTXS2MxD.ReadyxS = '1') then
        --                             SouthTXM2SxD.DataxD       <= SouthNativeMasterxD.DataxD;
        --                             SouthTXM2SxD.LastxS       <= '1';
        --                             SouthTXM2SxD.ValidxS      <= '1';
        --                             SouthNativeSlavexD.RdEnxS <= '1';
        --                             SouthStatusSendWordxDN    <= E_SEND;
        --                         end if;

        --                 when E_SEND =>
        --                         SouthStatusSendWordxDN <= E_IDLE;

        --                 when others => null;
        --             end case;
        --         end process SouthSendWordxP;

        --         WestSendWordxP : process (WestNativeMasterxD.DataxD,
        --                                   WestNativeMasterxD.EmptyxS,
        --                                   WestStatusSendWordxDP,
        --                                   WestTXS2MxD.ReadyxS) is
        --         begin  -- process WestSendWordxP
        --             WestTXM2SxD.DataxD       <= (others => '0');
        --             WestTXM2SxD.KeepxD       <= (others => '1');
        --             WestTXM2SxD.LastxS       <= '0';
        --             WestTXM2SxD.ValidxS      <= '0';
        --             WestNativeSlavexD.RdEnxS <= '0';
        --             WestStatusSendWordxDN    <= WestStatusSendWordxDP;

        --             case WestStatusSendWordxDP is
        --                 when E_IDLE =>

        --                         if (WestNativeMasterxD.EmptyxS = '0') and
        --                             (WestTXS2MxD.ReadyxS = '1') then
        --                             WestTXM2SxD.DataxD       <= WestNativeMasterxD.DataxD;
        --                             WestTXM2SxD.LastxS       <= '1';
        --                             WestTXM2SxD.ValidxS      <= '1';
        --                             WestNativeSlavexD.RdEnxS <= '1';
        --                             WestStatusSendWordxDN    <= E_SEND;
        --                         end if;

        --                 when E_SEND =>
        --                         WestStatusSendWordxDN <= E_IDLE;

        --                 when others => null;
        --             end case;
        --         end process WestSendWordxP;

        --         NorthFifoxI : entity work.scalp_packet_fifo_wrapper
        --             port map (
        --                 RdClkxCI        => AuroraClkMasterxC.UserClkxC,
        --                 WrClkxCI        => PSSysClkxC,
        --                 ResetxRI        => PSSysResetxR,
        --                 NativeSlavexDI  => NorthNativeSlavexD,
        --                 NativeMasterxDO => NorthNativeMasterxD);

        --         EastFifoxI : entity work.scalp_packet_fifo_wrapper
        --             port map (
        --                 RdClkxCI        => AuroraClkMasterxC.UserClkxC,
        --                 WrClkxCI        => PSSysClkxC,
        --                 ResetxRI        => PSSysResetxR,
        --                 NativeSlavexDI  => EastNativeSlavexD,
        --                 NativeMasterxDO => EastNativeMasterxD);

        --         SouthFifoxI : entity work.scalp_packet_fifo_wrapper
        --             port map (
        --                 RdClkxCI        => AuroraClkMasterxC.UserClkxC,
        --                 WrClkxCI        => PSSysClkxC,
        --                 ResetxRI        => PSSysResetxR,
        --                 NativeSlavexDI  => SouthNativeSlavexD,
        --                 NativeMasterxDO => SouthNativeMasterxD);

        --         WestFifoxI : entity work.scalp_packet_fifo_wrapper
        --             port map (
        --                 RdClkxCI        => AuroraClkMasterxC.UserClkxC,
        --                 WrClkxCI        => PSSysClkxC,
        --                 ResetxRI        => PSSysResetxR,
        --                 NativeSlavexDI  => WestNativeSlavexD,
        --                 NativeMasterxDO => WestNativeMasterxD);

        --     end block TxFifoxB;

        -- end block ZynqRegBankxB;

        DebugxB : block is
        begin  -- block DebugxB

            ClkEnxAS        : ClkEnxS              <= not AuroraClkMasterxC.PllNotLockedxS;
            -- North
            NorthTXDataxAS  : NorthTXM2SxD.DataxD  <= DataCounterxD;
            NorthTXKeepxAS  : NorthTXM2SxD.KeepxD  <= (others => '1');
            NorthTXLastxAS  : NorthTXM2SxD.LastxS  <= '0';
            NorthTXValidxAS : NorthTXM2SxD.ValidxS <= not DebugCounterResetxR;
            -- East            
            EastTXDataxAS   : EastTXM2SxD.DataxD   <= DataCounterxD;
            EastTXKeepxAS   : EastTXM2SxD.KeepxD   <= (others => '1');
            EastTXLastxAS   : EastTXM2SxD.LastxS   <= '0';
            EastTXValidxAS  : EastTXM2SxD.ValidxS  <= not DebugCounterResetxR;
            -- South
            SouthTXDataxAS  : SouthTXM2SxD.DataxD  <= DataCounterxD;
            SouthTXKeepxAS  : SouthTXM2SxD.KeepxD  <= (others => '1');
            SouthTXLastxAS  : SouthTXM2SxD.LastxS  <= '0';
            SouthTXValidxAS : SouthTXM2SxD.ValidxS <= not DebugCounterResetxR;
            -- West
            WestTXDataxAS   : WestTXM2SxD.DataxD   <= DataCounterxD;
            WestTXKeepxAS   : WestTXM2SxD.KeepxD   <= (others => '1');
            WestTXLastxAS   : WestTXM2SxD.LastxS   <= '0';
            WestTXValidxAS  : WestTXM2SxD.ValidxS  <= not DebugCounterResetxR;

            DataCounterxI : entity work.data_counter
                port map (
                    clk  => AuroraClkMasterxC.UserClkxC,
                    ce   => ClkEnxS,
                    sclr => DebugCounterResetxR,
                    q    => DataCounterxD);

            VioUserResetsxI : entity work.vio_user_resets
                port map (
                    clk           => AuroraClkMasterxC.UserClkxC,
                    probe_out0(0) => DebugCounterResetxR,
                    probe_out1(0) => DebugRXFifoResetxR,
                    probe_out2(0) => DebugBackPressureResetxR,
                    probe_out3    => open,
                    probe_out4    => open);

            -- VioAxiCntCtrlxI : entity work.vio_axi_cnt_ctrl
            --     port map (
            --         clk           => AuroraClkMasterxC.UserClkxC,
            --         -- North
            --         probe_in0     => NorthRXfromPhyTXfromFifoM2SxD.DataxD,  -- 32 bits
            --         probe_in1(0)  => NorthRXfromPhyTXfromFifoM2SxD.ValidxS,
            --         probe_in2(0)  => '0',  --NorthTXS2MxD.ReadyxS,
            --         -- East
            --         probe_in3     => EastRXfromPhyTXfromFifoM2SxD.DataxD,  -- 32 bits
            --         probe_in4(0)  => EastRXfromPhyTXfromFifoM2SxD.ValidxS,
            --         probe_in5(0)  => '0',  --EastTXS2MxD.ReadyxS,
            --         -- South
            --         probe_in6     => SouthRXfromPhyTXfromFifoM2SxD.DataxD,  -- 32 bits
            --         probe_in7(0)  => SouthRXfromPhyTXfromFifoM2SxD.ValidxS,
            --         probe_in8(0)  => '0',  --SouthTXS2MxD.ReadyxS,
            --         -- West
            --         probe_in9     => WestRXfromPhyTXfromFifoM2SxD.DataxD,  -- 32 bits
            --         probe_in10(0) => WestRXfromPhyTXfromFifoM2SxD.ValidxS,
            --         probe_in11(0) => '0',  --WestTXS2MxD.ReadyxS,
            --         probe_out0(0) => open); --CntRstxR);

            VioStatusxI : entity work.vio_status
                port map (
                    clk           => AuroraClkMasterxC.UserClkxC,
                    -- North
                    probe_in0(0)  => AuroraStatusxD.HardErrxD(0),
                    probe_in1(0)  => AuroraStatusxD.SoftErrxD(0),
                    probe_in2(0)  => AuroraStatusxD.FrameErrxD(0),
                    probe_in3     => AuroraStatusxD.LaneUpxD(0),
                    probe_in4(0)  => AuroraStatusxD.ChannelUpxD(0),
                    probe_in5(0)  => AuroraStatusxD.RXResetDoneOutxD(0),
                    probe_in6(0)  => AuroraStatusxD.TXResetDoneOutxD(0),
                    -- East
                    probe_in7(0)  => AuroraStatusxD.HardErrxD(1),
                    probe_in8(0)  => AuroraStatusxD.SoftErrxD(1),
                    probe_in9(0)  => AuroraStatusxD.FrameErrxD(1),
                    probe_in10    => AuroraStatusxD.LaneUpxD(1),
                    probe_in11(0) => AuroraStatusxD.ChannelUpxD(1),
                    probe_in12(0) => AuroraStatusxD.RXResetDoneOutxD(1),
                    probe_in13(0) => AuroraStatusxD.TXResetDoneOutxD(1),
                    -- South
                    probe_in14(0) => AuroraStatusxD.HardErrxD(2),
                    probe_in15(0) => AuroraStatusxD.SoftErrxD(2),
                    probe_in16(0) => AuroraStatusxD.FrameErrxD(2),
                    probe_in17    => AuroraStatusxD.LaneUpxD(2),
                    probe_in18(0) => AuroraStatusxD.ChannelUpxD(2),
                    probe_in19(0) => AuroraStatusxD.RXResetDoneOutxD(2),
                    probe_in20(0) => AuroraStatusxD.TXResetDoneOutxD(2),
                    -- West
                    probe_in21(0) => AuroraStatusxD.HardErrxD(3),
                    probe_in22(0) => AuroraStatusxD.SoftErrxD(3),
                    probe_in23(0) => AuroraStatusxD.FrameErrxD(3),
                    probe_in24    => AuroraStatusxD.LaneUpxD(3),
                    probe_in25(0) => AuroraStatusxD.ChannelUpxD(3),
                    probe_in26(0) => AuroraStatusxD.RXResetDoneOutxD(3),
                    probe_in27(0) => AuroraStatusxD.TXResetDoneOutxD(3));

        end block DebugxB;

    end block ProgrammableLogicxB;

end arch;
